---
name: Question
about: Ask us a question
title: "[QUESTION]"
labels: question
assignees: ''

---

<!--

Have a descriptive title.
Consult documentation before asking the question.
Try to be concise.
Try to give enough information.
  - What were you trying to do?
  - What happened?
Try not to ask rhetorical questions

If it is installation related, what is your OS? Python version? NumPy version? SciPy version?

-->
